@@ -1095,7 +1095,7 @@ e_book_backend_couchdb_load_source (EBookBackend *backend,
 	if (g_strcmp0 (property, "user") == 0) {
 		if (! (couchdb_backend->couchdb = COUCHDB_SESSION (desktopcouch_session_new ()))) {
 #if EDS_CHECK_VERSION(3, 1, 2)
-			e_book_backend_notify_opened (backend, e_data_book_create_error (E_DATA_BOOK_STATUS_OTHER_ERROR, _("Could not create DesktopcouchSession object")));
+			e_data_book_respond_open (book, opid, e_data_book_create_error (E_DATA_BOOK_STATUS_OTHER_ERROR, _("Could not create DesktopcouchSession object")));
 			return;
 #elif EDS_CHECK_VERSION(2, 31, 0)
 			g_set_error (ret_error, ERROR_QUARK, 100, _("Could not create DesktopcouchSession object"));
@@ -1116,7 +1116,7 @@ e_book_backend_couchdb_load_source (EBookBackend *backend,
 		if (! (couchdb_backend->couchdb = couchdb_session_new (uri))) {
 			g_free (uri);
 #if EDS_CHECK_VERSION(3, 1, 2)
-			e_book_backend_notify_opened (backend, e_data_book_create_error (E_DATA_BOOK_STATUS_OTHER_ERROR, _("Could not create CouchdbSession object")));
+			e_data_book_respond_open (book, opid, e_data_book_create_error (E_DATA_BOOK_STATUS_OTHER_ERROR, _("Could not create CouchdbSession object")));
 			return;
 #elif EDS_CHECK_VERSION(2, 31, 0)
 			g_set_error (ret_error, ERROR_QUARK, 100, _("Could not create CouchdbSession object"));
@@ -1145,10 +1145,10 @@ e_book_backend_couchdb_load_source (EBookBackend *backend,
 		if (only_if_exists) {
 #if EDS_CHECK_VERSION(3, 1, 2)
 			if (error) {
-				e_book_backend_notify_opened (backend, e_data_book_create_error (E_DATA_BOOK_STATUS_NO_SUCH_BOOK, error->message));
+				e_data_book_respond_open (book, opid, e_data_book_create_error (E_DATA_BOOK_STATUS_NO_SUCH_BOOK, error->message));
 				g_error_free (error);
 			} else {
-				e_book_backend_notify_opened (backend, e_data_book_create_error_fmt (E_DATA_BOOK_STATUS_NO_SUCH_BOOK, _("Could not open database %s"), db_name));
+				e_data_book_respond_open (book, opid, e_data_book_create_error_fmt (E_DATA_BOOK_STATUS_NO_SUCH_BOOK, _("Could not open database %s"), db_name));
 			}
 			return;
 #elif EDS_CHECK_VERSION(2, 31, 0)
@@ -1173,7 +1173,7 @@ e_book_backend_couchdb_load_source (EBookBackend *backend,
 						      db_name,
 						      &error)) {
 #if EDS_CHECK_VERSION(3, 1, 2)
-			e_book_backend_notify_opened (backend, e_data_book_create_error (E_DATA_BOOK_STATUS_PERMISSION_DENIED, error->message));
+			e_data_book_respond_open (book, opid, e_data_book_create_error (E_DATA_BOOK_STATUS_PERMISSION_DENIED, error->message));
 #elif EDS_CHECK_VERSION(2, 31, 0)
 			g_propagate_error (ret_error, error);
 #endif
@@ -1241,7 +1241,7 @@ e_book_backend_couchdb_load_source (EBookBackend *backend,
 #endif
 #if EDS_CHECK_VERSION(3, 1, 2)
 	e_book_backend_notify_online (backend, TRUE);
-	e_book_backend_notify_opened (backend, NULL);
+	e_data_book_respond_open (book, opid, NULL);
 #elif EDS_CHECK_VERSION(2, 31, 0)
 	e_book_backend_notify_connection_status (backend, TRUE);
 #else
